unit ucuEmprestarLivro;


interface

uses
  utuStateMachine, utuRequest, ucuUseCase;

type
  ucEmprestarLivro = class(ucUseCase)
  public
    procedure Initialize; Override;
    procedure Finalize; Override;
  published
    procedure Effect_PesquisarUsuario(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_EscolherUsuario(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_PesquisarExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_CancelarEscolhaExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_ConcluirEdicaoEmprestimo(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_RemoverExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_ConfirmarEmprestimo(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_CancelarEmprestimo(piRequest: utRequest; piTransition: utTransition);
  end;

implementation

uses
  ucuManager,
  utuMessage {define utField},
  acuFramework,
  utuEmprestimoOQL,
  acuObject {define acEnumerator},
  nguCliente;


procedure ucEmprestarLivro.Initialize;
begin
  inherited;
end;

procedure ucEmprestarLivro.Finalize;
begin
  
  inherited;
end;

procedure ucEmprestarLivro.Effect_PesquisarUsuario(piRequest: utRequest; piTransition: utTransition);
var
  lFieldUsuario,
  lFieldUsuarios: utField;
  lOQL: IObterClientes;
  lListUsuarios: acPersistentObjectList;
  lEnumUsuario: acEnumerator;
  lUsuario: ngCliente;
begin
  lFieldUsuario := piRequest.Message.RootField.FieldByName('Cliente');

  lOQL := utEmprestimoOQL.ObterClientes(Self.Session);

  lFieldUsuarios := piRequest.Response.RootField.AddField('Cliente');

  lListUsuarios := acPersistentObjectList.Create(ngCliente);
  try

    if lFieldUsuario.HasAttribute('Nome')
      then lOQL.Param_nome.Value := lFieldUsuario.AttributeByName('Nome').AsString
      else lOQL.Param_nome.SetNull;

    if lFieldUsuario.HasAttribute('CPF')
      then lOQL.Param_cpf.Value := lFieldUsuario.AttributeByName('CPF').AsString
      else lOQL.Param_cpf.SetNull;

    lOQL.LoadList(lListUsuarios);

    lEnumUsuario := acEnumerator.Create(lListUsuarios);
    try
      while not lEnumUsuario.EOL do
      begin
        lUsuario := lEnumUsuario.Current as ngCliente;
        lUsuario.toXML(lFieldUsuarios.AddField('Cliente'));
        lEnumUsuario.MoveNext;
      end;
    finally
      lEnumUsuario.Free;
    end;


  finally
    lListUsuarios.Free;
  end;

  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_EscolherUsuario(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_PesquisarExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_CancelarEscolhaExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_ConcluirEdicaoEmprestimo(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_RemoverExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_ConfirmarEmprestimo(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEmprestarLivro.Effect_CancelarEmprestimo(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;


initialization

  gucManager.RegisterClass(3219,ucEmprestarLivro);

end.
